#
# spec file for package openttd
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2007-2012 The OpenTTD developers
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define about OpenTTD is a reimplementation of the Microprose game "Transport Tycoon Deluxe" with lots of new features and enhancements. To play the game, you need either the original proprietary data set from the game, or install the recommend subpackages OpenGFX, OpenSFX and OpenMSX for an alternate, free set of graphics, sounds and music, respectively.
Name:           openttd
Version:        13.4
Release:        1.1
Summary:        A clone of Chris Sawyer's Transport Tycoon Deluxe
License:        GPL-2.0-only
Group:          Amusements/Games/Strategy/Other
URL:            https://openttd.org/
Source:         https://cdn.openttd.org/openttd-releases/%{version}/%{name}-%{version}-source.tar.xz
# PATCH-FEATURE-UPSTREAM https://bugs.openttd.org/task/6490
Source2:        openttd.appdata.xml
BuildRequires:  SDL2-devel
BuildRequires:  cmake
BuildRequires:  fdupes
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++ >= 8.1
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-io)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-data = %{version}-%{release}
Conflicts:      %{name}-dedicated
Provides:       %{name}-gui = %{version}
%if 0%{?mdkversion}
BuildRequires:  liblzma-devel
BuildRequires:  liblzo-devel
%else
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig(liblzma)
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
BuildRequires:  pkgconfig(freetype2)
%else
BuildRequires:  freetype-devel
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libtimidity)
BuildRequires:  pkgconfig(libxdg-basedir)
%else
BuildRequires:  desktop-file-utils
BuildRequires:  grfcodec
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
Recommends:     adobe-sourcehansans-fonts
Recommends:     openttd-openmsx
Recommends:     openttd-opensfx
%endif

%description
%{about}

Use package %{name}-dedicated for systems without SDL.

%package dedicated
Summary:        OpenTTD Dedicated Server binary (without SDL)
Group:          Amusements/Games/Strategy/Other
Requires:       %{name}-data = %{version}-%{release}
Conflicts:      %{name}

%description dedicated
%{about}

This package provides the binary %{name}-dedicated without dependency of SDL.

%package data
Summary:        OpenTTD data
Group:          Amusements/Games/Strategy/Other
%if 0%{?suse_version} || 0%{?fedora} || 0%{?mdkversion} || 0%{?rhel_version} >= 600 || 0%{?centos_version} >= 600
BuildArch:      noarch
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
Recommends:     openttd-opengfx >= 0.5.2
%endif

%description data
%{about}

This package provides the data files needed by %{name} or %{name}-dedicated.

%prep
%setup -q

# Remove build time references so build-compare can do its work
sed -i "s/__DATE__.*__TIME__/\"${SOURCE_DATE_EPOCH}\"/" src/rev.cpp.in

%build
%if 0%{?suse_version} <= 1500
export CXX=g++-10
%else
export CXX=g++
%endif
export CXXFLAGS=-fPIE
# first, we build the dedicated binary inside dedicated/
%define __builddir dedicated
%cmake -DCMAKE_INSTALL_BINDIR="bin" -DCMAKE_INSTALL_DATADIR="share" -DOPTION_DEDICATED:BOOL=ON
%cmake_build
cd ..

# then, we build the common gui version which we install the usual way
%define __builddir build
%cmake -DCMAKE_INSTALL_BINDIR="bin" -DCMAKE_INSTALL_DATADIR="share" -DOPTION_DEDICATED:BOOL=OFF
%cmake_build

%install
# install the game
%cmake_install INSTALL_DIR=%{buildroot}

# install the dedicated server
install -D -m0755 dedicated/openttd %{buildroot}%{_bindir}/%{name}-dedicated

mkdir -p %{buildroot}%{_datadir}/appdata
install -D -m0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/openttd.appdata.xml

%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%endif

%post dedicated
rm -f %{_bindir}/%{name}
ln -s %{name}-dedicated %{_bindir}/%{name}

%preun dedicated
if [ "$1" -eq 0 ] ; then
    rm -f %{_bindir}/%{name}
fi

%if 0%{?suse_version} < 1500
%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/openttd.appdata.xml
%{_datadir}/icons/hicolor
%{_datadir}/pixmaps/%{name}.32.xpm
%{_datadir}/pixmaps/%{name}.64.xpm
%{_mandir}/man6/%{name}.6%{?ext_man}

%files dedicated
%{_bindir}/%{name}-dedicated
%{_mandir}/man6/%{name}.6%{?ext_man}

%files data
%{_datadir}/doc/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/lang
%{_datadir}/%{name}/baseset
%{_datadir}/%{name}/scripts
%{_datadir}/%{name}/ai
%{_datadir}/%{name}/game

%changelog
* Sun Jul 30 2023 Jan Baier <jbaier@suse.com>
- update to 13.4
  - Fix: Setting tree lines drawn incorrectly for RTL languages (#11070)
  - Fix #11043: Don't choose toolbar dropdown option if focus is lost (#11044)
  - Fix #10917: Pay loan interest before generating statistics (#11040)
  - Fix #11016: Use after free in network invalid packet error path (#11022)
  - Fix #10987: Double-close of dropdown stopped land-info tool working as default (#11000)
* Mon Jun 12 2023 Jan Baier <jbaier@suse.com>
- update to 13.3
  - Fix: make sure multiplayer games work as expected
* Sat Jun 10 2023 Jan Baier <jbaier@suse.com>
- update to 13.2
  - Change: Automatically disable hardware acceleration when GPU driver crashed the game last attempt (#10928)
  - Change: [Linux] Default scroll mode to non-mouse-lock (#10920)
  - Change: Include font style in font name for Freetype (#10879)
  - Fix: Don't restore backed up vehicle name if it's no longer unique (#10979)
  - Fix #10975: Train name wrongly marked as unique when joining trains (#10976)
  - Fix: Crash when not even a single row fits for dropdowns on low resolution screens (#10934)
  - Fix: Crash with tooltip on low resolution screens (#10933)
  - Fix: Crash when window can't be placed on low resolution screens (#10932)
  - Fix #10502: Apply engine refit before attaching free wagons (#10926)
  - Fix: Wayland crash on startup due to Pango also using FontConfig (#10916)
  - Fix: When syncing width of GUI items, take padding into account (#10915)
  - Fix: Make dropdowns self-close when losing focus (#10912)
  - Fix: Land info window maximum width was not scaled (#10894)
  - Fix: Check max member count in squirrel classes (#10883)
  - Fix: Ask FontConfig for the face index when opening fonts (#10878)
  - Fix #10831: Level crossing parts left barred after crossing tile removal (#10874)
  - Fix: Rail waypoint selection window not closed when parent windows closed (#10873)
  - Fix #10846: [Script] Crash on trying to allocate an excessively large array (#10848)
  - Fix: [Emscripten] Crash when saving games (#10758)
  - Fix #10741: Rail platforms left partially reserved after train crash (#10751)
  - Fix: Shaded engines in purchase list incorrectly shaded (#10736)
  - Fix #10735: [NewGRF] {POP_COLOUR} fails if string is drawn with extra flags (#10736)
  - Fix #8177: Ships with max speed overflow to near-zero speed (#10695)
  - Fix #10289: Don't silently fail when setting timetable start dates (#10690)
  - Fix #8302: Improve "Maintenance intervals are in percents" helptext (#10686)
  - Fix #10665: "No vehicles are available yet" message did not appear correctly on non-temperate climates (#10673)
  - Fix #10630: Don't allow shifting service date earlier than year 0 (#10643)
  - Fix #10637, #10638: Incorrect water infrastructure totals when building certain object types (#10639, #10640)
  - Fix: Abort loading savegame if road vehicle is on invalid road type (#10622)
* Wed Apr 12 2023 Jan Baier <jbaier@suse.com>
- update to 13.1
  - Add: [NewGRF] Engine name callback for nested variants. (#10399)
  - Fix: Improve main toolbar tooltips (#10616)
  - Fix: [NewGRF] Additional validation for Action3 (+others) (#10601)
  - Fix: Clear button for editbox didn't take account of padding (#10583)
  - Fix: [Script] Access to enum/consts defined outside of main.nut (#10573)
  - Fix #10568: Bogus warning when loading a save with a NewGRFs on dedicated servers (#10572)
  - Fix #10554: Crash when scrolling in the autoreplace window with collapsed variants (#10555)
  - Fix: Network server highlight invisible with RTL languages. (#10551)
  - Fix: Client name was not being used as company manager name (#10535)
  - Fix: Prevent road vehicles on crossing from crashing into the side of a train (#10496)
  - Fix #10477: [macOS] Calculation for window sizes when using custom fonts was being rounded incorrectly (#10489)
  - Fix #10486: Crash in debug window when GS started before AIs (#10487)
  - Fix #10469: [Script] Negative numbers in League Table window were sorted incorrectly (#10471)
  - Fix #10465: Crash on timeout if user never enters a password for server (#10466)
  - Fix #10280, #10461: Crash on opening town windows as a spectator (#10462)
  - Fix #10059: Script config values stored in the config file could cause crashes (#10444)
* Mon Feb  6 2023 Jan Baier <jbaier@suse.com>
- update to 13.0
  - Change #10077: Make maximum loan a positive multiple of the loan interval (#10355)
  - Fix #10361: [Script] Don't try to give saved data to a dead script (#10433)
  - Fix #10419: Water infrastructure accounting when building ship depots and docks (#10432)
  - Feature: Press Ctrl to build a diagonal area of trees (#10342)
  - Feature: Set a custom number of industries in map generation window (#10340)
  - Change: Display font status as aa/noaa instead of true/false (#10352)
  - Fix: [Script] Improved API documentation for scripts (#10413, #10412)
  - Fix #10255: Reduce basic thickness of linkgraph GUI lines (#10410)
  - Fix #10220: Don't select unselectable engine as default (#10404)
  - Fix #10395: When loading old saves, don't forcibly bar level crossings (#10400)
  - Fix #10377: Bad sorting of rail vehicles when primary variant is missing (#10378)
  - Fix #10368: Server restarting game caused clients to hit assertion (#10369)
  - Fix #10362: NewGRF bridges without speed limits (#10365)
  - Fix #10363: CargoDist setting helptext shouldn't suggest symmetric distribution for diamonds in subtropic (#10364)
  - Fix: [Script] Switch to OWNER_TOWN prevented OWNER_DEITY test during industry prospecting (#10360)
  - Fix #10009: Bad overflow protection when taking out loans (#10359)
  - Fix #9865: Removing files with the console always failed (#10357)
  - Fix #10057: FallbackParagraphLayout fails to properly wrap (#10356)
  - Fix #10177: Company list password padlock showed after switching to single player (#10354)
  - Fix: Various Wide River issues (#10348)
  - Fix: Link variants to parents when finalising engines (#10346)
  - Fix #10333: Only show industry prospecting errors to local company (#10338)
  - Fix #10335: Set initial scrollbar count for object GUI (#10336)
  - Fix #10331: Starting new company during load must happen after AI start (#10332)
  - Fix #10309: [SDL] Uninitialized width and height when turning off full screen (#10328)
  - Fix #10032: Capacities of articulated vehicles in build window (#10326)
  - Fix: Improve handling of corrupt NewGRF or image files (#10321, #10316)
  - Fix: [NewGRF] Don't assume engclass 2 should be elrail (#10315)
  - Fix: [Script] AIGroup.GetProfitLastYear could get values different than those displayed in GUI (#10227)
  - Fix #10304: [Scripts] Don't start GS in intro game (#10305)
  - Fix: [Script] Copy compat files for version 13 (#10303)
  - Feature: 'font' console command to configure fonts within game (#10278)
  - Feature: Ctrl-click to bulk edit timetable speeds/waiting times (#10265)
  - Feature: [NewGRF] Vehicle variants in expandable purchase list (#10220)
  - Feature: Expand all towns in the scenario editor (#10215)
  - Add: [NewGRF] Slope-aware and roadtype-specific one-way sprites (#10282)
  - Change: Display text files in black (#10291)
  - Change: Make vehicle list dropdown buttons resize to fit strings (#10286)
  - Change: [NewGRF] Support flipping shorter engines without explicit support (#10262)
  - Change: Separate ground sprite from foundation sprite offsets (#10256)
  - Change: Vertically centre sprite font relative to TrueType font (#10254)
  - Change: [macOS] Set minimum macOS version to 10.13 (#10253)
  - Change: Use lowered not disabled widget for current vehicle details tab (#10252)
  - Change: Various improvements to NewGRF sprite aligner (#10249)
  - Change: reset_engines console command now rerandomises introduction dates and reliability (#10220)
  - Change: Show error message on failed industry prospecting (#10202)
  - Fix: Local authority window rating list height ignored icon sizes (#10285)
  - Fix #10150: Town signs could be truncated when using custom fonts (#10283)
  - Fix #8971: Resize QueryStrings with interface scale change (#10281)
  - Fix #10274: Crash when rescanning scripts with GS selected (#10276)
  - Fix #10151: Use smaller padding for signs (#10272)
  - Fix #10263: [Script] Restore tile validation for commands (#10269)
  - Fix: Missing scrollbar for rail/roadtype dropdowns (#10264)
  - Fix #10260: Incorrect rect height drawing image in vehicle details (#10261)
  - Fix #10257: Incorrect catenary position on sloped bridge heads (#10258)
  - Fix: Vertically centre chat prompt (#10250)
  - Fix #10214: League and graph buttons in toolbar did not have a default action (#10246)
  - Fix #10242: Allow a space for text shadow when clipping text (#10243)
  - Fix #10206: Fully disable scripts in intro game (#10241)
  - Fix #10218: Don't try to create river tiles along incorrect slopes (#10235)
  - Fix #10208: [NewGRF] Allow using a specific underlay for road/tram tunnels (#10233)
  - Fix #10224: Don't change fast-forward mode while saving (#10230)
  - Fix #10147: Sound effect volume slider no longer set volume (#10228)
  - Fix #10223: Crash when vehicle cloning fails on order cloning (#10225)
  - Fix: Maximum space for engine preview image was never scaled (#10219)
  - Fix #10216: Crash when upgrading savegame with crashed vehicles (#10217)
  - Fix #10212: [Script] Nested ScriptAccounting scopes not restored properly (#10213)
  - Fix #10114: Incorrect drag-highlight position with non-power-of-2 scaling (#10211)
  - Fix #10198: Rearrange Intro GUI to make button rows narrower (#10203)
  - Fix: Missing extra padding when drawing tooltip text (#10201)
  - Fix: Bad alignment of button icons when using the original baseset (#10200)
  - Fix: Signal icons incorrectly positioned in UI (#10199)
  - Fix #10021: Object GUI resized when switching between different objects (#10196)
  - Fix #9720: Delay start of GS/AI to after loading of savegame (#9745)
  - Feature: Allow AI/GS to be fully modified in scenario editor (#10152)
  - Feature: Display power-to-weight ratio in ground vehicle details GUI (#10123)
  - Feature: Variable interface scaling (with chunky bevels!) (#10114)
  - Feature: Hotkey to honk a vehicle's horn (#10110)
  - Feature: Split AI/Game Script configuration windows and add them to world gen window (#10058)
  - Feature: [GS] Scriptable league tables (#10001)
  - Feature: Multi-track level crossings (#9931)
  - Feature: Improved local authority action window (#9928)
  - Feature: Automatic console command screenshot numbering with a filename ending in '#' (#9781)
  - Feature: Add buttons to toggle music in the Game Options menu (#9727)
  - Feature: Contextual actions for vehicles grouped by shared orders (#8425)
  - Feature: Add cargo filter support to vehicle list (#8308)
  - Feature: Show the cargoes the vehicles can carry in the vehicle list window (#8304)
  - Change: Allow building canal by area outside editor (#10173)
  - Change: Minor improvements to the new Finance GUI (#10168)
  - Change: Let AI developers edit non-editable AI/Game Script Parameters (#8895)
  - Change: Allow building docks on clearable watered object tiles (#8514)
  - Fix #8770: Center vehicle status bar icon (#10178)
  - Fix: Crash if error message window is too wide for screen. (#10172)
  - Fix #10155: Network games not syncing company settings properly (#10158)
  - Fix #10154: Network game desync related to setting a random company face (#10157)
  - Fix #10011: Incorrect infrastructure totals when overbuilding bay road stop (#10143)
  - Fix #10117: Object burst limit allowed one fewer object than the setting (#10120)
  - Fix #10023: Allow negative input in text fields when needed (#10112)
  - Fix #9908: Fix crash which could occur when a company was deleted when a depot window was open (#9912)
  - Feature: Airport construction GUI displays infrastructure cost (#10094)
  - Feature: Purchase land multiple tiles at a time (#10027)
  - Feature: Add sticky pin & shade widgets to Object Selection UI panel (#10019, #10020)
  - Feature: Improved handling of HiDPI and mixed-DPI screens (#9994, #9996, #9997, #10064)
  - Feature: Alternative linkgraph colour schemes (#9866)
  - Feature: Allow Shift+Insert as paste in edit box (#9836)
  - Feature: Setting to make the local town authority rubber-stamp all actions (#9833)
  - Feature: Add/extend console commands to enable screenshot automation (#9771)
  - Feature: [Linkgraph] Show a tooltip with statistics when hovering a link (#9760)
  - Feature: Build objects by area (#9709)
  - Feature: Add setting to hide news about competitors vehicle crash (#9653)
  - Feature: Ctrl-click to remove fully autoreplaced vehicles from list (#9639)
  - Feature: Wide rivers on map generation (#9628)
  - Add: [Script] ScriptCargo::GetWeight to get cargo weights (#9930)
  - Add: Command line option to skip NewGRF scanning (#9879)
  - Add: Show video driver name in Game Options window (#9872)
  - Add: [NewGRF] Map seed as global variable (#9834)
  - Add: [Script] IndustryType::ResolveNewGRFID to resolve industry id from grf_local_id and grfid (#9798)
  - Add: [Script] ObjectType::ResolveNewGRFID to resolve object id from grfid and grf_local_id (#9795)
  - Update: To all the friends we have lost and those we have gained (#10000)
  - Change: Use the Simulation subcategory to openttd.desktop (#10015)
  - Change: Constantly update destination of 'any depot' orders (#9959)
  - Change: Use an indent, not a dash, to list train capacity (#9887)
  - Change: [NewGRF] Increase vehicle sprite stack from 4 layers to 8 (#9863)
  - Change: Don't pay Property Maintenance on stations when Infrastructure Maintenance is disabled (#9828)
  - Change: Improved layout of the finance window (#9827)
  - Change: [Admin] Bump admin port protocol due to command changes (#9754)
  - Change: Suppress vehicle age warnings for stopped vehicles (#9718)
  - Change: Make pf.yapf.rail_firstred_twoway_eol on by default (#9544)
  - Change: Deliver cargo to the closest industry first (#9536)
  - Fix: Lots of fixes to how windows handle resizing (#10040, #10042, #10046, #10051, #10056, #10068, #10070, #10098)
  - Fix: Console commands list_ai output was truncated with a suitably large number of AIs (#10075)
  - Fix #9876: MacBook Touch Bar crash / render issues w/ 32bpp graphics (#10060)
  - Fix: Reduce framerate overhead in Train::Tick (#10055)
  - Fix: Only open scenario editor date query once (#10050)
  - Fix #10048: Don't relocate company HQ on the same exact location (#10049)
  - Fix #10038: Missing upper bounds check when loading custom playlists (#10039)
  - Fix: Wrong string used to determine size of zoomed out station sign (#10036)
  - Fix: Disable "turn around" button for other companies' road vehicles (#10033)
  - Fix: Online Players list mouse hover behaviour (#10031)
  - Fix: [NewGRF] Weirdness of new stations (#10017)
  - Fix #9854: DrawStringMultiLine() could draw beyond its bounding box (#10014)
  - Fix: Incorrect player name in online players window (#10013)
  - Fix #8099: News window zoom level fixes (#10005)
  - Fix: [NewGRF] Upper 16 random bits should be the same for all station tiles in callback 140 (#9992)
  - Fix #9989: Â£0 Net Profit is neither negative nor positive (#9991)
  - Fix #9804: Only apply sprite_zoom_min setting when sprites available (#9988)
  - Fix #9972: Add missing fill/resize flags on Framerate window widgets (#9982)
  - Fix #9935: Use more selectivity when building SSE specific code (#9980)
  - Fix #9940: Print debuglevel parse errors to console when changed from console (#9979)
  - Fix #9977: Clearing the console with a large number of lines could cause a crash (#9978)
  - Fix #9974: Console command getsysdate did not work due to off-by-one error (#9975)
  - Fix: [NewGRF] Default value of RailVehicleInfo::railveh_type was inconsistent with other default properties (#9967)
  - Fix #8584: Vehicles with shared orders getting invalid or unexpected start dates (#9955)
  - Fix #9951: [NewGRF] Scenario editor random industries button broke NewGRF persistent storage (#9952)
  - Fix: Validation of various internal command parameters that could have allowed a rogue client to crash servers (#9942, #9943, #9944, #9945, #9946, #9947, #9948, #9950)
  - Fix #9937: Station industries_near incorrect after removing part moved sign (#9938)
  - Fix: [Script] ScriptRoad::HasRoadType really check for RoadType (#9934)
  - Fix #9363: Rebuild client list on reinit event (#9929)
  - Fix #9925: Industry tile layout validation for layouts of only one tile (#9926)
  - Fix #9918: Reset industy last production year on scenario start (#9920)
  - Fix #9914: Prevent more useless pathfinder run for blocked vehicles (#9917)
  - Fix: List a max of four share owners instead of three (#9905)
  - Fix: [NewGRF] Industry layouts with zero regular tiles should be invalid (#9902)
  - Fix #9869: Remove docking tile when doing a clear square (#9898)
  - Fix: New player companies use favorite manager face, if saved (#9895)
  - Fix: Towns don't build parallel, redundant bridges (#9891)
  - Fix #9712: Cap town bridge length at original 11-tile limit (#9890)
  - Fix #9883: Show cost/income float over end tile of rail or road construction (#9889)
  - Fix #9870: Don't update infrastructure totals when overbuilding object on canal (#9888)
  - Fix #9877: GS could trigger 'Cost: Â£0' cost message (#9878)
  - Fix 44f2ef1: [strgen] Allow gender for {CARGO_SHORT} (#9873)
  - Fix #9867: Industry::stations_near not filled at industry creation (#9868)
  - Fix #9853: Incorrect merge of guiflags and flags for osk_activation (#9855)
  - Fix #6544: Don't join AI company when loading network game in singleplayer (#9794)
  - Fix: Company values do not properly account for shares (#9770)
  - Fix #9546: Crash when no industries are present in game (#9726)
  - Fix #9708: [Linkgraph] Don't assume vehicles have a non-zero max speed (#9693)
  - Fix #9665: [Linkgraph] Fix travel times of non-direct journeys (#9693)
  - Fix #8797: Use logical rail length when placing signals (#9652)
  - Cleanup: [NewGRF] Remove unused flag sprites (#10052)
* Mon May 16 2022 Jan Engelhardt <jengelh@inai.de>
- Because SDL2 was pulled in by fluidsynth, openttd opportunistically
  built itself with SDL2, ignoring the SDL1 BuildRequire. Now make
  SDL2 explicit.
* Thu Apr  7 2022 Carsten Ziepke <kieltux@gmail.com>
- Fix building for openSUSE Leap, using gcc10-c++
* Sat Apr  2 2022 Jan Baier <jbaier@suse.com>
- update to 12.2
  - Feature: Remember the last-used signal between games (#9792)
  - Change: Add a timestamp in name of crash files (#9761)
  - Fix #9736: Duplicate multiplayer window opens upon canceling password entry (#9842)
  - Fix: Removing long roads doesn't prioritise refusal of local authority over other errors (#9831)
  - Fix #9020: Glitchy station coverage highlight when changing selection (#9825)
  - Fix: Correct some Romanian town names (#9819)
  - Fix: Original music playback rate was slightly too fast (#9814)
  - Fix #9811: Use the NewGRF-defined vehicle center when dragging ships and aircraft (#9812)
  - Fix: Do not let shares in the company taking over another company disappear (#9808)
  - Fix #9802: Crash when using lots of NewGRF waypoint types (#9803)
  - Fix #9766: Don't write uninitialised data in config file (#9767)
  - Fix #9774: Building roadstop in estimation mode updates station acceptance (#9775)
  - Fix: If vehicles only refit to cargo-slots >= 32, the default cargo was wrong (#9744)
  - Fix #9735: Possible desync when replacing a depot on same tile (#9738)
  - Fix #9730: [Network] Connections can use an invalid socket due to a race condition (#9731)
  - Fix: Don't show sign edit window for GS-owned signs (#9716)
  - Fix #9702: Display order window for vehicle group on ctrl-click only when using shared orders (#9704)
  - Fix #9680: Crash when loading really old savegames with aircraft in certain places (#9699)
  - Fix: Update last servicing dates when using the date cheat (#9694)
  - Fix: Error message shows about missing glyphs while suitable fallback font is found (#9692)
* Sat Nov 27 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Add FluidSynth support (for music playback).
* Fri Nov 12 2021 Jan Baier <jbaier@suse.com>
- update to 12.1:
  - Feature: Button to toggle showing advanced signal types (#9617)
  - Change: Don't show screenshot GUI in screenshots (#9674)
  - Change: Suppress panning in intro game, while user is interacting with the GUI (#9645)
  - Change: Draw rotor in cursor when dragging helicopters in depots (#9612)
  - Fix: Invalid memory access when loading a currency NewGRF (#9675)
  - Fix #9579: Object and HQ construction is Construction cost, not Property Maintenance (#9673)
  - Fix #9669: Ships exiting a blocked depot/lock could exit in the wrong direction (#9672)
  - Fix: Every 16th client never reconnects after server restart (#9666)
  - Fix #9643: Screenshots were always written as BMP files (#9644)
  - Fix #9630: Intro game could zoom in/out more than allowed by settings (#9633)
  - Fix #9626: Incorrect loading of script saved data (#9629)
  - Fix: Emergency crash save had the wrong NewGRF list saved in it (#9627)
  - Fix #9595: Always use plural forms of cargo for subsidy strings (#9619)
  - Fix #9614: Refresh rate dropdown was still active when vsync was enabled (#9618)
  - Fix: Don't use 'server address' string in server list when displaying an invite code (#9615)
* Thu Oct 21 2021 Jan Baier <jbaier@suse.com>
- update to 12.0:
  - Add: [Network] Keep the refresh button in lowered state while refreshing (#9600)
  - Add: Console command to list search directories for various things (#9583)
  - Fix: Try all possible reverse directions when a ship reaches a dead end (#9610)
  - Fix: Incorrect Romanian own name (#9598)
  - Fix #9591: Update station docking tiles upon placing a water object on a docking tile (#9594)
  - Fix #9548: [Squirrel] Crash during engine cleanup after reaching memory limit on realloc (#9592)
  - Fix #9588: [Squirrel] Reaching memory limit during script registration could prevent further script detections (#9589)
  - Fix: Make ships more likely to find their destination at the cost of slightly worse paths (#9576)
  - Change: Reverse ship when leaving docks if a better path exists (#9610)
  - Change: Allow all tiles around docks to be docking tiles (#9578)
  - Feature: Display icon/text whether vehicle is lost in vehicle (list) window (#9543)
  - Feature: Button to open order window from vehicle shared orders window (#9325)
  - Feature: Ctrl-Clicking shared order vehicle list opens order window (#9325)
  - Feature: Multiple rotating views on title screen (#8980)
  - Feature: Hide block signals in GUI by default (#8688)
  - Add: [Script] Allow GameScripts to build neutral objects (#9568)
  - Add: [Network] Allow sending chat messages via admin port (#9563)
  - Add: [AI/GS] Missing water related functions and objects (#8390)
  - Fix: Industry funding window did not update when changing funding method (#9572)
  - Fix #9562: [NewGRF] Handle case of invalid Action2 with zero results (#9564)
  - Fix: Incorrect error messages when placing water in scenario editor (#9560)
  - Fix #9484: Update locale currencies settings config map (#9559)
  - Fix: Prevent train reversing when entirely inside a train depot (#9557)
  - Fix: [Network] Add back 'Spectate' option to company toolbar menu (#9556)
  - Fix #8603: Don't give focus to text filter when opening Object GUI (#9547)
  - Fix #9241: Grove and forest tree brushes did not also create rainforest terrain (#9542)
  - Fix: [Network] Several crashes in our network code (#9534, #9456)
  - Fix #9527: Crash when trying to place multi-tile objects at map edge (#9529)
  - Fix: [Network] SendCmdNames only sent one name per packet (#9528)
  - Fix #9407: Desync when founding a town nearby a station (#9526)
  - Fix #9521: Don't load at just removed docks that were part of a multi-dock station (#9524)
  - Fix: Ships always tried to avoid docking tiles when pathfinding (even if nothing was on them) (#9522)
  - Fix: [Network] Convert server_advertise to server_game_type in config file (#9515)
  - Fix #9490: [Network] A full server couldn't be queried (#9508)
  - Fix: [Network] Don't show GameScript " (v0)" for old servers (#9507)
  - Fix: [Network] Show query errors in the server listing instead of error popup (#9506)
  - Fix: [Network] Crash when last-joined server was no longer available (#9503)
  - Fix #9501: [Network] Crash when more than one game-info query was pending (#9502)
  - Fix: Wrong error message when building canals over ship depots / locks (#9410)
  - Fix: Reduce cost of building canals over objects on sea (#9410)
  - Change: [Linkgraph] Delete links only served by vehicles stopped in depot (#9499)
  - Feature: [Linkgraph] Prioritize faster routes for passengers, mail and express cargo (#9457)
  - Fix: Wrong town window refreshed when building an airport with noise levels enabled (#9497)
  - Fix: Improve wording of network-related messages (#9494, #9495, #9500)
  - Fix: [Network] Report reuse of invite-code (#9487)
  - Fix: [Network] Connecting with the same client name thrice hangs the server (#9485)
  - Feature: [Network] Remove lobby window; pressing "Join Game" now immediately joins a server (#9467)
  - Feature: [Network] Synchronize server name to clients and display in Online Players window (#9472)
  - Feature: [Network] Mention you are a spectator in the status bar (#9471)
  - Feature: [Network] No longer require port-forwarding to host a server (#9443, #9447)
  - Feature: [Network] Allow setting your server visibility to "invite-only" (#9434)
  - Feature: [Network] Join servers based on their invite code (#9432)
  - Feature: Raise the maximum NewGRF limit to 255 (#9428)
  - Feature: Persistent rotation of numbered auto/netsave after restart (#9395, #9397)
  - Feature: [NewGRF] Maximum curve speed modifier for rail vehicles (#9346)
  - Feature: Move sensitive information to secrets.cfg and private information to private.cfg (#9298)
  - Feature: [NewGRF] Define refittability of default vehicles using cargo classes (#9148)
  - Feature: Configurable subsidy duration, up to 5000 years (#9081)
  - Feature: [Network] Rework in-game Online Players window (#9067)
  - Feature: [Network] Show previous chat history when the chat message box is open (#9025)
  - Feature: Button to reset game settings to their default values (#8958)
  - Feature: Press Ctrl to build diagonal rivers in Scenario Editor (#8880)
  - Feature: Set wagon replacement per group when using autoreplace (#7441)
  - Add: [Network] Open Online Players window on starting/joining a server (#9479)
  - Add: [Script] Basic information about loaded NewGRFs for scripts (#9464)
  - Add: [AI] Get the number of vehicles in a given group (#9462)
  - Add: [Network] Inform network clients what game-script a server is running (#9441)
  - Add: Hindi translation (#9086)
  - Add: [Network] Ensure players fill in a name instead of defaulting to "Player" (#9080)
  - Change: Allow pause/unpause console command in single player (#9342)
  - Change: Make savegame format self-descriptive and consistent across all objects (#9322, #9335, #9338, #9339)
  - Change: By default, make "unload all" leave stations empty (#9301)
  - Change: Reworked the debug levels and messages for network logs (#9230, #9251)
  - Change: [Emscripten] Set default scrolling mode to non-pointer-locking (#9191)
  - Change: Use neutral pronouns for various strings (#9189, #9203, #9228)
  - Change: Make the town directory horizontally resizable (#9157)
  - Change: Allow non-ASCII currency separators (#9121)
  - Change: [NewGRF] Display a pop-up window for Errors with severity ERROR (#9119)
  - Change: Treat languages as finished, if translations are 75%% completed (#9019, #9086)
  - Change: Disable NewGRF window apply button if no change was made (#8934)
  - Fix: [Script] Crash when iterating lists of which the key is larger than 32bit (#9465)
  - Fix: [Network] Desync due to use of unstable sort when distributing cargo production (#9460)
  - Fix #9440: Negative cargo payments not being handled correctly (#9455)
  - Fix: [Network] Crash when joining a server again after a TCP disconnect (#9453)
  - Fix: Don't enable rename button for network clients in build vehicle window (#9452)
  - Fix: Money could underflow and wrap around (#9451)
  - Fix: Parse the console settings the same way as config settings (#9438)
  - Fix: Ensure no more than the allowed number of NewGRFs are loaded from the configuration (#9430)
  - Fix: [NewGRF] Overflow when determining cargo mask for string code 9A 1E (#9423)
  - Fix: Integers for scripts are 64bit, but saved as 32bit (#9415)
  - Fix #9392: [Script] Return a valid value with GetBuildWithRefitCapacity even when AIs are maxed out in vehicles (#9393)
  - Fix #8169: Crash when autoreplacing vehicle with no orders (#9387)
  - Fix: Wrong cargo line position in IndustryCargo window (#9383)
  - Fix: Race-condition during startup of NewGRF scan (#9382)
  - Fix: Don't propagate Shift/Ctrl state till next game-tick (#9381)
  - Fix: Prevent palette updates during copying to the video driver (#9379)
  - Fix: [Network] Determining GetNetworkRevisionString could overflow and underflow its buffer (#9372)
  - Fix #9358: Don't skip empty files in tar archives (#9367)
  - Fix: For old savegames, station bus/truck station cache was not updated (#9366)
  - Fix #9353: [Script] Garbage collecting on priority queues could crash the game (#9356)
  - Fix: Respect the autosave_on_exit setting for Null video driver (#9343)
  - Fix: Compatible NewGRFs in crash-log reported wrong MD5 hash (#9340)
  - Fix: [Script] Ensure the saved script strings are properly validated and terminated (#9336)
  - Fix #9316: Town bridge length limit check incorrect above 250k inhabitants (#9318)
  - Fix: Limit heightmap sizes to 8192x8192 (#9307)
  - Fix #9281: Money generating exploit when buying out a company (#9300)
  - Fix: Part of a tile might not be redrawn when terraforming (#9296)
  - Fix: [OpenGL] Increase timeout when waiting for the GPU to be done with the drawing buffer (#9282)
  - Fix: Vehicles sent in the wrong direction if there is no path to the destination (#9280)
  - Fix #9264: Do not attach temporary wagons to free wagon chains when autoreplacing (#9278)
  - Fix #9267: [Script] Crash during garbage collection (#9275)
  - Fix: Encountering two-way red signals could prune unrelated Pathfinder branches (#9271)
  - Fix #9255: [Network] Crash when hostname is not found (#9259)
  - Fix #9256: Invalid read after free when replacing train chains (#9258)
  - Fix: [Emscripten] Force secure WebSockets over HTTPS (#9248)
  - Fix #9242: Tree tick handler did not scale by map size (#9246)
  - Fix: [Network] Mark server as offline when no longer reachable (#9244)
  - Fix: [Network] Don't rebuild the host-list during iterating the list (#9240)
  - Fix: [Network] Don't mark the last-joined server as a manually added server (#9239)
  - Fix: [Network] Clients leaving because of broken connections was not broadcasted (#9238)
  - Fix: [Network] Check on CIDR for netmask check considered everything valid (#9235)
  - Fix: Creating screenshots on dedicated servers failed (#9232)
  - Fix: Leaking file descriptors for downloaded content (#9229)
  - Fix: Spelling of several town names (#9222)
  - Fix #9209: Game hangs when resizing highscore/news window if the screen is too small (#9210)
  - Fix: [Network] Optimize creating network connections for clients using IPv4 and IPv6 (#9199)
  - Fix #9186: Fix incorrect bounding box height causing station sprite glitch (#9187)
  - Fix: Truncating strings in settings could leave invalid UTF-8 characters (#9121)
  - Fix: Many issues related to window scaling (#9087, #9219)
  - Fix: Invalidate cached vehicle colourmaps when changing liveries setting (#9006)
  - Fix #8981: Don't attempt to re-reserve path if already entering/entered depot (#9000)
  - Fix: Missing 'Town names:' colon in map gen GUI (#8986)
  - Fix: Sorting and filtering industries that produce/accept many cargoes (#8468)
  - Remove: [Network] COMPANY_INFO packets (#9475)
  - Remove: [Network] A server can no longer set a limit to the amount of spectators allowed (#9466)
  - Remove: Arbitrary limit on number of statically loaded NewGRFs (#9431)
  - Remove: [Network] Language and map-name from server information (#9070)
* Mon May  3 2021 Jan Baier <jbaier@suse.com>
- update to 1.11.2:
  - Change: More improvements to the GUI at different scales (#9075, #9102, #9107, #9133, #9174, #9183)
  - Fix: Query windows could be partially drawn (#9184)
  - Fix #9113: Crash when removing an airport that exists in an aircraft's orders (#9182)
  - Fix #9117: [Fluidsynth] Hang when changing song (#9181)
  - Fix: String validation could leave invalid UTF-8 encoded strings (#9096)
  - Fix: [Network] Out-of-bounds memory access with modified servers sending too short password salts (#9176)
  - Fix: Crash when extra viewport with zero height has sign in view (#9175)
  - Fix #9147: Crash when taking screenshots (#9169)
  - Fix #6598: [Network] Prevent crashes when (re)joining network game by falling back to main menu first (#9163)
  - Fix #9152: Screenshot success popup window was treated as an error (#9159)
  - Fix: Fast-forward stuttering when vsync is enabled (#9140)
  - Fix: [Network] Savegame transfer could stall in rare cases (#9106)
  - Fix #9097: [NewGRF] Cargo initial payment variable was being truncated (#9098)
  - Fix: [NewGRF] Industry variable 66 and object variable 46 erroneously truncated the distance (#9088)
  - Fix: [NewGRF] Industry variables 65 and 66 ignored the parameter, and always used the north tile (#9088)
  - Fix: Do not include regression test AI in bundle (#9068, #9164)
* Wed Apr 21 2021 Jan Baier <jbaier@suse.com>
- update to 1.11.1:
  - Feature: Toggle to enable/disable vsync (#8997)
  - Feature: Volume controls in the Game Options window, and better defaults (#8943)
  - Add: Hotkey to focus object and rail filters (#8908)
  - Add: Better plural support for Romanian (#8936)
  - Change: Improve layout and spacing of several windows at different GUI scales (#9041, #9042, #9044, #9050)
  - Change: Make effect volume scale more intuitively (#8945, #8950)
  - Change: Improve padding of Object & Rail station windows (#8929)
  - Fix #6322: [Script] Crash when script allocates too much memory, now kills script instead (#9047)
  - Fix #7513: [Script] Crash on garbage collection with misbehaving script (#9040)
  - Fix #9028: [OpenGL] Crash when changing max sprite zoom level (#9032)
  - Fix #8874: show a warning when a NewGRF scan is requested multiple times (#9022)
  - Fix: Desync when GS unlocks railtype with wagon unlock (#9021)
  - Fix #9008: Validate starting year given on the command line (-t) (#9014)
  - Fix #8878: [Network] Slow DNS queries could block the server and disconnect clients (#9013)
  - Fix: Improve validation of OpenGL video driver to avoid crashes (#9007)
  - Fix: Credits scrolled too slowly with larger font sizes (#8994)
  - Fix #8977: Crash when altering max sprite resolution (#8993)
  - Fix #8956: Industry disaster news messages showed the wrong location (#8992)
  - Fix: [Network] Potential stale client entries in client list (#8959)
  - Fix: Graphical issues when dragging measurement tooltips (#8951)
  - Fix: [Fluidsynth] Use provided default soundfont if available (#8948, #8953)
  - Fix #8935: [macOS] Crash on save (#8944)
  - Fix #8922: Crash when selling shared vehicles with shared vehicle window open (#8926)
  - Fix: Compiling on armhf (Raspberry Pi) (#8924)
* Mon Apr 12 2021 Jan Baier <jbaier@suse.com>
- update to 1.11.0:
  - Feature: Allow setting a custom terrain type to define highest peak (#8891)
  - Feature: Auto-detect map height limit based on generated map (#8891)
  - Feature: Setting to indicate desert coverage for tropic climate and snow coverage for arctic climate (replaces snow line height) (#8891)
  - Add: Allow setting the highest mountain for heightmaps (#8891)
  - Change: Scale exported heightmaps to highest peak and inform the user of this value (#8891)
  - Change: Remove "maximum map height" from the New Game GUI (#8891)
  - Fix #8803: Only auto-remove signals when rail can be built (#8904)
  - Fix #8565: Stopped road vehicle displays a speed different than 0 (#8901)
  - Fix #8886: Don't try to resolve folders within tars named '.' (#8893)
  - Fix: Placing random trees in SE crashes the game (#8892)
  - Fix #8875: Filter string in station window breaks flow in user interface (#8885)
  - Fix #8871: [OpenGL] Initialize all buffers after resize and clear back buffer (#8877)
  - Fix: OpenGL performance with some AMD GPUs (#8876)
  - Fix: Recompute road/railtype availability after disabling the engine (#8872)
  - Fix: OSK layout not scaled for 2x or 4x GUI scale (#8868)
  1.11.0-RC1 (2021-03-14)
  - Feature: Option to (dis-)allow hardware accelerated video drivers (#8819)
  - Feature: Option to set display refresh rate (#8813)
  - Feature: Allow custom width/height of screenshot and making heightmap screenshots via console (#8804)
  - Feature: Allow filtering on name in rail station window (#8706)
  - Feature: Setting for highest resolution of sprites to use (#8604)
  - Add: Make NewGRF Scanner / World Generation update smoother and make aborting it react faster (#8830)
  - Add: Malaysia Ringgit as Currency (#8783)
  - Add: "Engines only" filter in build train window (#8733)
  - Change: De-limit framerate window's framerate (#8772)
  - Change: Clarify what effect town interactions have (#8744)
  - Change: Don't show global goals in company goal windows (#8709)
  - Change: Recolour graph windows to brown (#8700)
  - Fix #8855: Bootstrap could result in an empty screen when bootstrap fails (#8856)
  - Fix #8851: Don't allow infinite "exec" depth in script, but limit to 10 deep (#8852)
  - Fix #8647: Incorrect drawing order of tram catenary sprites (#8843)
  - Fix #8711: Having gui_zoom lower than zoom_min causes a crash (#8835)
  - Fix #8810: "aircraft out of fuel" news shows the wrong place (#8832)
  - Fix #8833: Don't reload NewGRFs when we are shutting down (#8830)
  - Fix: Scale padding between elements the same as other padding (#8829)
  - Fix #8808: [OSX, OpenGL] Crash on switching blitters due to double-mapping the video buffer (#8822)
  - Fix #8784: Using Alt+Enter doesn't update the fullscreen toggle visibly (#8820)
  - Fix #8817: Keep NewGRF order for object class sorting (#8818)
  - Fix #8809: Crash when removing airport when hangar window open (#8815)
  - Fix #8799: Crash when Search Internet in Multiplayer (#8801)
  - Fix #8774: Black screenshots when using 40bpp-blitter (#8791)
  - Fix: [OSX] Hide dock when entering fullscreen (#8789)
  - Fix: Bootstrap fails to start on clean install (#8788)
  - Fix: Terraform limit acts random when maxing out per_64k_frames setting (#8782)
  - Fix: Max-value of fast-forward-speed-limit can be outside its storage size (#8769)
  1.11.0-beta2 (2021-02-28)
  - Feature: Add setting to limit fast-forward speed (#8766)
  - Feature: Significant performance improvements to all video drivers (#8605, #8652, #8660, #8685, #8702, #8703, #8707, #8726, #8740)
  - Feature: Configurable display refresh-rate, default to 60fps (#8680)
  - Feature: Automatically upload releases to Steam (#8644)
  - Feature: Generic Linux builds (#8641)
  - Feature: [GS] Allow non-question type windows to have no buttons (#8638)
  - Feature: [macOS] ZIP build (#8614)
  - Feature: Object class selection string filtering (#8603)
  - Feature: 'Remove all industries' button in scenario editor (#8550)
  - Feature: Automatic UI and font zoom levels when supported by the OS (#8537)
  - Feature: [macOS] Render screen at native resolution by default for HiDPI screens (#8519)
  - Feature: OpenGL video driver (#7744)
  - Add: Indonesia Rupiah currency (#8616)
  - Change: Improve graph period markings (#8732)
  - Change: Make pathfinder account for maximum order speed, if set (#8722)
  - Change: Darken graph grid lines for legibility (#8690)
  - Change: Make order window hotkeys toggle for load & unload variants (#8669)
  - Change: Use a more specific error message when attempting to bulldoze your own HQ (#8667)
  - Change: Move the 'tree placer algorithm' & 'road drive side' settings to the Settings window (#8566)
  - Change: Move town name generator selection to mapgen GUI (#8566)
  - Change: [macOS] Native font rendering (#8518)
  - Fix: Display of network lobby windows for different GUI sizes (#8765)
  - Fix: Don't desync if client leaves before you finish downloading map (#8755)
  - Fix: Allow estimating vehicle clone cost even if short on money (#8748)
  - Fix: Don't notify twice that a client left because of a timeout (#8746)
  - Fix: Vehicle cursor size did not account for the interface zoom level (#8739)
  - Fix #8123: Trams on half-tiles couldn't find depots (#8738)
  - Fix #8276: [NewGRF] Crash when an object's size was not set (#8719)
  - Fix #8349: Close depot vehicle list windows when closing the depot window (#8717)
  - Fix #8594: [NRT] Road pathfinder did not account for roadtype speed limits or lengths of tunnels/bridges (#8710)
  - Fix: Whole status bar instead of money widget refreshed on money change (#8692)
  - Fix: Unnecessary status bar redraws when there is no news to show (#8691)
  - Fix: New orders are non-stop by default (#8689)
  - Fix: Framerate window showed a slightly higher rate than actually measured (#8682)
  - Fix: Autorenew failure advice due to bad refit being shown to all companies (#8681)
  - Fix #8625: Wrong ending year was displayed in highscore table (#8672)
  - Fix #8620: Scale spacing between date & news in history window according to font scaling (#8671)
  - Fix: Mention our websites with https:// (instead of http://) (#8657)
  - Fix: [Emscripten] Open links in browser (#8655)
  - Fix: Don't crash when towns upgrade road tiles during expansion (#8651)
  - Fix #8029: [SDL2] Blank display when under Wayland (#8648)
  - Fix: Default Network Server List sorter put compatible servers in wrong order (#8626)
  - Fix: Use non-pulsating red highlight for coverage (#8622)
  - Fix: Center text and image in vehicle statusbar vertically (#8602)
  - Fix: Don't walk out of the map when trying to build tunnels (#8600)
  - Fix: Off-by-one error in desert/rainforest positioning at world gen (#8588)
  - Fix #8037: Crash when restarting AI that is controlling the same company as the player (#8587)
  - Fix: Stopped ships shouldn't block depots (#8578)
  1.11.0-beta1 (2021-01-22)
  - Feature: [GS] Ability to set some extra text in the industry window (#8576)
  - Feature: Show rainforest under vegetation on smallmap (#8562)
  - Feature: Automatically determine window size on new install (#8536)
  - Feature: Towns can build tunnels (#8473)
  - Feature: Make maximum length of town bridges depend on population (with a minimum limit of 4) (#8439)
  - Feature: New icons for renaming and go-to-location on GUI windows, and improve consistency of usage (#8455)
  - Feature: Add an option to disable tree growth completely (#8415)
  - Feature: Support for Emscripten (play-OpenTTD-in-the-browser!) (#8355)
  - Feature: Show group name as part of the default vehicle name (#8307)
  - Feature: "Frozen" economy setting that stops production changes and industry closures (#8282)
  - Feature: New velocity unit "tiles/day" (#8278)
  - Feature: Option to automatically remove signals when placing rail (#8274)
  - Feature: Increase max possible distance from border for oil refineries and rigs (#8237)
  - Feature: Improve tree planting window, and allow planting 'clumps' of trees by dragging in the scenario editor (#8234)
  - Feature: Indian Rupee (INR) currency (#8136)
  - Feature: [GS] Ability to give a company exclusive access to an industry (#8115)
  - Feature: Hotkeys for Land Info window, News window & close error window (#8053, #8266)
  - Feature: Improve rendering of large viewports (#7962)
  - Feature: [GS] Influence industry production changes from GameScript (#7912)
  - Feature: [GS] Push-buttons on storybook pages (#7896)
  - Feature: Option to group vehicle lists by shared orders (#7028)
  - Feature: Drag-and-drop vehicles in group GUI for shared order groups (#7028)
  - Add: [GS] A tile parameter to GSCompany::ChangeBankBalance for showing changes more visually (#8573)
  - Add: [NewGRF] Allow NewGRF vehicles to query the current rail/road/tram type (#8554)
  - Add: [Script] ScriptCargo::GetName for the human readable name of cargoes (#8544)
  - Add: "reload" console command to reload the current scenario or heightmap (#8527)
  - Add: [NewGRF] Flag to test if inflation is on or off (#8427)
  - Add: [Script] Native priority queue (useful for things like pathfinders) (#8091)
  - Add: [NewGRF] Industry behaviour flag to override second cargo production clamping for water industries when using smooth economy (#8079)
  - Change: [SDL2] Start game on the screen where the cursor is (#8572)
  - Change: Use a dark background for all profit graphs to increase contrast (#8557)
  - Change: Reword warning in cheat window (#8538)
  - Change: Enable the toolbar for road/rail/dock/airport, regardless of vehicle availability (#8521)
  - Change: For arctic and tropical climates, make sure at least a few hills are generated (#8513)
  - Change: Destroying a tunnel/bridge now sells the tracks before destroying the tunnel/bridge (#8508)
  - Change: Move "give money" from client-list to company window (#8500)
  - Change: [MacOS] Hide Dock and menu when in fullscreen mode (#8487)
  - Change: Improve performance for complex vehicle chains by resolving sprites less frequently (#8485)
  - Change: Make engine reliability independent of introduction date (#8470)
  - Change: Some default settings to improve gameplay for new players - default non-stop orders on, disable inflation, quick goto orders, show track reservations, and more (#8463)
  - Change: Converting town-owned road types now requires a positive town rating (#8457)
  - Change: Rework server list buttons for searching LAN/internet servers (#8426)
  - Change: Add some styling to GS question windows depending on the type (#8422)
  - Change: [Linkgraph] Speed up game exit by allowing job threads to be aborted early (#8416)
  - Change: Prevent towns from building dead-end road bridges (#8401)
  - Change: Send network error to the server before making an emergency save (#8387)
  - Change: Extend the allowed range for max loan setting up to Â£2 billion (#8386)
  - Change: Don't display OS name when exiting the game (#8366)
  - Change: Save openttd.cfg immediately on changing a setting (#8358)
  - Change: Autorenew now defaults to on (#8352)
  - Change: [NewGRF] Also use aircraft property 12 for helicopters (#8347)
  - Change: Service at depot also resets breakdown chance (#8317)
  - Change: Use key names instead of characters in hotkey.cfg (#8291)
  - Change: Allow command cost-estimation while paused (#8222)
  - Change: Always apply inflation from 1920 to 2090, no matter the game start year (#7589)
  - Change: Use CMake for build system (#7270)
  - Change: [Linkgraph] Pause the game when linkgraph jobs lag (#7081)
  - Change: Place "Group by" above "Sort by" in station window for consistency (#7028)
  - Fix #8589: Prevent desyncs with vehicle motion counters and NewGRFs (#8591)
  - Fix #7670: Improve pathfinder performance when lost vehicles are blocked from moving (#8568)
  - Fix: Inform user if a custom font failed to load due to missing glyphs (#8559)
  - Fix: Don't allow wagon chains (without an engine) to exceed maximum train length (#8533)
  - Fix #7619: Super fast NewGRF aircraft could be unable to land (#8531)
  - Fix: Improve connection retries for the content server in cases of broken networking (#8530)
  - Fix #7972: Show invalid orders to stations that don't accept the vehicle (#8516)
  - Fix: Error when trying to clone a vehicle with invalid orders (#8515)
  - Fix #8050: Various off-by-one errors in how the end-year of the game was used (#8512)
  - Fix #8332: Aborting vehicle group drag & drop could cause crashes (#8511)
  - Fix #8168: Allow relocating HQ partially over an existing HQ (#8510)
  - Fix #8068: Allow selling tram track regardless of bank balance (#8509)
  - Fix #7604: Prevent houses from wandering away from roads (#8507)
  - Fix: Make the "password" button the same size as the other buttons in the Company window (#8500)
  - Fix #7611: Keep news about vehicle accidents around after the vehicle is cleaned up (#8497)
  - Fix: [MacOS] Full animation in fullscreen mode was reducing the height of the window (#8491)
  - Fix: [MacOS] Loading custom fonts (#8484)
  - Fix: Network client makes emergency saves twice if the server is disconnected (#8477)
  - Fix #8462: Stop towns from trying to build roads on water (#8471)
  - Fix: [NewGRF] GetCurveSpeedLimit should use the railtype from the current tile (#8466)
  - Fix #8437: Crash when using certain heliports with certain rotated airports (#8458)
  - Fix #8437: Planes would land at the wrong height if the top corner of the airport was lowered (#8458)
  - Fix #8297: Infrastructure counters for road tunnels, bridges & depots (#8454)
  - Fix #6468: Don't store the version of AIs that are started via console (#8430)
  - Fix: Don't lower tree density if spreading is not enabled (#8413)
  - Fix: Prevent savegame version conflicts with certain old patchpacks (#8411)
  - Fix: [NewGRF] Variable 0x44 was always HZB_TOWN_EDGE for road stops (#8400)
  - Fix #8313: Use correct capitalization for TTO / DOS music files in the baseset metadata (#8385)
  - Fix: [NewGRF] Action 7/9 conditions 0x0F to 0x12 failed, if 'param' was 0x88 (#8382)
  - Fix: Change the working-dir searchpath when using '-c' (#8367)
  - Fix: Useless warning with -snull and no BaseSounds available (#8361)
  - Fix: Crash trying to load TTO/TTD savegames. (#8356)
  - Fix: [Script] Don't echo script exceptions to console (#8331)
  - Fix: Slovak ownname was using the wrong form (#8326)
  - Fix #8311: [NewGRF] Industry probability at map generation was scaled differently when set via property or callback (#8312)
  - Fix: Only check houses for cargo when generating subsidies with towns (#8305)
  - Fix: Sprite preview in sprite aligner was too small with scaled UI (#8288)
  - Fix: Spell 'Viewport' consistently (#8260)
  - Fix #7772: Show vehicle destination on mouseover when vehicle stopped (#8236, #8543)
  - Fix #8232: Huge screenshot warning was shown incorrectly (#8224)
  - Fix #8153: Report incompatible cargo/order when autoreplace fails (#8169)
  - Fix: [Script] ScriptMarine::AreWaterTilesConnected did not work for aqueducts (#8074)
  - Fix #7645: Add cost of clearing the sloped tile to the price of a dock (#7947)
  - Fix #6452: Reset only editable and visible settings from GUI (#7890)
  - Fix: Original terrain generator did not keep a single gap of water at the borders (#7883)
  - Remove: In-game console command "content select all" (#8363)
  - Remove: [OSX] Support for OSX older than 10.7, including QuickTime music driver (#8078)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.10.3:
  Fix: Center text and icons in the status bar vertically (#8273)
  Fix: [NRT] Set invalid road and tram types for rail tunnel ends (#8269)
  Fix #7980: Properly invalidate mouse-over station coverage highlight (#8263)
  Fix #8250: [NRT] Company infrastructure window always omits last road/tramtype (#8251)
  Fix #8162: [NRT] Improve error message when converting town owned road (#8247)
  Fix #8216: Don't show floating text on autoreplace if cost is 0 (#8244)
  Fix #8129: Crash if a news message expires while viewing the endgame screen (#8243)
  Fix #8221: Use more specific error message when a bridge is too long (#8240)
  Fix #8230: Resolve ".." when opening files in .tar (#8231)
  Fix: A few race conditions in netcode (#8227, #8228, #8229)
  Fix #7838: Crash relating to group creation and renaming (#8223)
  Fix #8104: [SDL2] Fix window resizability when going from fullscreen to windowed mode (#8211)
  Fix: Display banlist's indexes correctly (#8209)
  Fix: Possible desync with subsidy creation (#8159)
  Fix #8131: Draw small bridges pillars in more places (#8149)
  Fix: [OSX] Possible crash on failure to set colourspace (#8181)
  Fix #8166: Prevent crash from a NewGRF with an invalid RoadType (#8180)
  Fix #8024: Make Online Content GUI more responsive while loading (#8179)
  Fix #7970: Disable event loop when generating crash dump (#8176)
  Fix: [Build] Compatibility with modern Visual Studio (#8170)
  Fix: Trees would disappear completely after a few years if tree spread was disabled (#8160)
  Fix #8155: Roadtype speed limit in scenario editor toolbar dropdown was doubled (#8156)
  Fix: Desync after house replacement (#8151)
  Fix #8137: New clients can't join (desync) after funding an industry (#8140)
  Fix #8132: Corrupted savegame with station with multiple owners caused a crash (#8134, #8142)
  Fix: Stop gamelog when recovering from a savegame load error (#8133)
  Fix: Exceptionally unlikely issue when reading MIDI files (#8125)
  Fix #8119: Docking areas were not properly updated when clearing, causing desyncs (#8124, #8130)
  Fix #8117: Memory leak for incoming admin port packets (#8122)
  Fix: Non-roadbridges potentially had roadtype information set (#8111)
  Fix #8108: Possible crash on loading TTD savegames with phantom oil rigs (#8109, #8110)
  Fix #8093: Build & refit test run changed game state and could cause desyncs (#8103)
  Fix: [Script] AreWaterTilesConnected did not handle aqueducts properly (#8074)
* Sat Apr 11 2020 dsterba@suse.cz
- Update to 1.10.0
  - Change: Open company window when clicking on a company goal (#8033)
  - Change: [SDL2] Support pasting from clipboard on Linux (#8004)
  - Fix: Station with multiple docks had the wrong tile area (#8014)
  - Fix #7958: Custom catenary missing on road bridges (#7991)
  1.10.0-RC1 (2020-02-09)
  - Feature: Allow server to supply a reason to kicked/banned clients (#7859)
  - Feature: [NewGRF] Station variable 6A, querying GRFID of nearby station tiles (#7956)
  - Feature: Improved logic of sharing industry production between 3 or more stations (#7922)
  - Feature: Highlight the item under mouse cursor in file browser (#7900)
  - Feature: [GS] Methods to change town rating of companies (#7898)
  - Feature: [NewGRF] Callback profiling command (#7868)
  - Feature: Add a setting to show the name of the NewGRF of a vehicle in the build window (#7852)
  - Feature: Ability to filter industry directory window by cargo (#7843)
  - Feature: Minimap screenshot type (#7817)
  - Feature: [GS] Methods to control engine availability of a specific company (#7791)
  - Feature: Configurable game ending year (#7747)
  - Feature: Separate window for taking screenshots (#7550)
  - Change: Move autorenew setting to basic category (#7984)
  - Change: Improved algorithm for transfer feeder payments (#7935)
  1.10.0-beta2 (2019-12-25)
  - Feature: Ctrl+Click on a vehicle in the vehicle group window selects and scrolls to the vehicle's group (#7800)
  - Feature: Ctrl+Click on the vehicle details button in the vehicle view window opens the vehicle group window focused on the vehicle (#7800)
  - Feature: Add a button to the vehicle advisory news window to open the vehicle's group window (#7800)
  - Feature: Ctrl+Click on a vehicle in the vehicle list window opens the vehicle group window focused on the vehicle's group (#7800)
  1.10.0-beta1 (2019-10-29)
  - Feature: Configurable minimum age for companies before allowing share trading (#7780)
  - Feature: Filter on town list window (#7621)
  - Feature: Ability to show Newspaper and Ticker messages in parallel (#7612)
  - Feature: Show coverage area for stations and towns (#7446)
  - Feature: Collapsible vehicle groups (#7417)
  - Feature: More flexible docks - can now have multiple per station, ships can use any part of dock (#7380)
  - Feature: [NewGRF] Railtype flags to allow/disallow 90 degree curves (#7352)
  - Feature/Change: Non-rectangular catchment area for sparse stations (#7235)
  - Feature: Improved performance for road vehicle pathfinding (#7261)
  - Feature: Option to show local authority boundary of towns (#7025)
  - Feature: Experimental method of town cargo generation that scales linearly with population (#6965)
  - Feature: [NewGRF] RoadTypes (NRT) (#6811)
  - Add: 'getsysdate' console command (#7658)
  - Add: Currencies NTD, CNY, HKD (#7596)
  - Add: Icons to vehicle construction drop down lists (#7358, #7485)
  - Add: Security warning to players that company passwords are not truly secure (#7351)
  - Add: [Script] Various API functions for managing vehicle groups (#7225, #7336, #7716)
  - Add: SDL2 video driver (#7086)
  - Change: Inactive industries do not make sound effects (#7752)
  - Change: Scale oil refinery edge distance limit by map size (#7514)
  - Change: Do not display a news message about old vehicles when a replacement for it is activated (#7401)
  - Change: When filtering purchase list by cargo type, buy button now performs a refit if required (#7301)
  - Change: Don't apply forbid 90 deg turn settings to ships, and make penalties for turns configurable (#7289, #7372)
  - Change: Make the chance of an aeroplane crashing at an airport with a short runway independent of plane crash setting (#7302)
  - Change: Keep town growth rate in sync with house count (#6777)
* Sat Nov  2 2019 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to 1.9.3
  * Change: Use natural sort when sorting the file list
  * Fix: Don't close construction windows when changing client name
- Update to 1.9.3-RC1
  * Add: Can now click industries to make orders to their neutral
    station (e.g. oil rig)
  * Fix: Highscore screen UI scaling
  * Fix: [AI] Possible crash when reloading an AI in multiplayer games
  * Fix: RemoveAirport function now returns 'Aircraft in the way'
    error message when occupied
  * Fix: Spelling in running costs setting help text
  * Fix: 'Decrease' buttons in cheat window not working properly with
    UI scaling
  * Fix: [GS] Could not create elements on Storybook pages with ID > 255
  * Fix: Allow building road stops over town-owned one-way roads,
    instead of crashing
* Mon May 27 2019 Jon Brightwell <jon@moozaad.co.uk>
- removed old ICU patch ( fix_issue6690_compilation_with_icu61.patch ). Bugtracker MIA (#6690) and no longer is needed
- Update to 1.9.1
  1.9.1 (2019-04-08)
- Fix #6564: Enforce types of arguments for station name strings (#7419)
- Fix #7433: Don't use AirportSpec substitute if it's not enabled (#7435)
- Fix #7447, #7466, #7476: Missing NewGRF strings due to Action 4 feature check skipping pseudo-feature 48 (#7449)
- Fix #6222: Advanced sprite layout sometimes showed incorrect railtype ground tile. (#7460)
- Fix #7439: CompanyRemoveReason overwritten by ClientID (#7465)
- Fix #7478: Don't remove NewGRF objects on company take-over. (#7483)
  1.9.0 (2019-04-01)
- Fix #7411: Use industry production callback (if used) on initial industry cargo generation (#7412)
  1.9.0-RC2 (2019-03-24)
- Fix #7400: WaterClass for tree tiles was not converted for old saves preventing industry creation (#7405)
- Fix: Filtered file list did not scroll properly (#7402)
- Fix #7391: Don't invalidate go to depot orders of non-aircraft when invalidating hangar orders that happen to share IDs (#7392)
- Fix #7386: Measurement tooltip for tunnels, aqueducts & docks did not display or flickered (#7389)
- Fix: Wrong company performance rating when money exceeds INT_MAX (#7382)
- Fix: Permit loading of industry production callback with invalid cargo type (#7364)
- Fix: Spelling for a few real town names (#7338)
- Fix: Runway too short for large aircraft message should not depend on plane crashes setting (#7325)
- Fix #7334: Ship lost after crossing bridge due to path cache not being consumed while on final bridge end (#7335)
  1.9.0-RC1 (2019-03-03)
- Add: Various AI/GS functions for vehicle groups (#7225)
- Change: Synchronise introduction date and reliability randomness across vehicles with the same base introduction date (#7147)
- Change: Allow towns to build bridges over rails and one-way roads (#7291)
- Fix: Detection of coast tiles with trees on them (#7309)
- Fix: Emergency netsave saved the title game instead of the broken game in question (#7298)
- Fix: Company livery window showed incorrect groups when opened in multiplayer (#7288)
- Fix: Unable to select last group in open livery window (#7283)
- Fix: Goto hangar orders were not invalidated when rebuilding airports (#7100)
  1.9.0-beta3 (2019-02-24)
- Feature: Option to adjust font size separately from GUI size (#7003)
- Feature: Increase maximum number of orders from 64000 to ~16.7m (#7220)
- Add: Show performance of AI and GS in framerate window
- Add: News menu entry and shortcut for deleting all messages (#7240)
- Change: [OSX] Improved scrolling behaviour when using touchpads
- Change: Add scrollbar to cargo legend in cargo payment rates window
- Change: Owner of vehicle with exclusive transport rights may now load cargo from neutral stations (#7256)
- Change: Improved UI behaviour when dragging sound volume sliders with the mouse (#7227)
- Change: Use selected vehicle group as parent when creating a new group (#7224)
- Change: Use SlErrorCorrupt() on pool index error when loading a savegame, instead of terminating (#7219)
- Change: Skip reliability decay if servicing is disabled
- Fix: Remove desert around lakes upon generation
- Fix: Re-sorting file list did not update filtered rows
- Fix #7159: Waiting time at red one-way signals was too short
- Fix #7189: Fluidsynth volume gain too high
- Fix #7004: Cargo flow legend was not properly refreshed after zooming (#7265)
- Fix: Possibility to modify wrong AI/GS settings when switching AI/GS scripts around (#7090, #7091)
- Fix: Use more descriptive "spectator" strings for story book and goal dropdown menus
- Fix #6599: Disable build and rename button in build vehicle window when no vehicle is selected
- Fix: Do not mangle tagged revision strings for network revision strings
- Fix #7151: AI start date deviation was still applied when not set to a random AI (#7223)
- Fix #7197: Invalidate depot buttons when necessary (#7212)
- Doc: [AI] UnshareOrders empties the orders list of the vehicle
  1.9.0-beta2 (2019-02-09)
- Fix: Non-Windows builds did not get correct git hash
  1.9.0-beta1 (2019-02-09)
  Note: OpenTTD was migrated to GitHub for 1.9, so SVN revision and FlySpray numbers have been replaced with Pull Requests and Issue numbers
- Feature: Group liveries, and livery window usability enhancements (#7108)
- Feature: Overhaul of music system, support MPSMIDI music files (TTD DOS/TTO) (#6839)
- Feature: [Linux] New Fluidsynth music driver
- Feature: Framerate display window (#6822)
- Feature: [NewGRF] Ability for industries & houses to produce and/or accept up to 16 different cargoes
- Feature #6610: Allow towns to build houses on road turns (#6758)
- Feature: Replace independent map scrolling GUI settings with single option, and add choice to not lock cursor position when scrolling (#6756)
- Feature #6459: API for querying network clients from GS (#6736)
- Feature: New Russian Ruble & Mexican Peso as currencies (#6678, #7035)
- Feature #4186: Append '(City)' after city names in the town directory
- Feature #986: Automatic save when losing connection to a network game
- Add: [NewGRF] Flag to hide rail types from construction (#7118)
- Add: [NewGRF] Airport animation trigger for plane landing (#6334)
- Add #4115: Default starting company colour setting (#6998)
- Add: Mixer feature for streaming sampled music
- Add #6460: [AI] start_date parameter for Random AIs on new game
- Add: BACKSPACE can be mapped as a hotkey
- Add: 32bpp SSE2 blitter palette animator (#6795)
- Change: Make ships turn slowly when changing direction and stop when going up or down a lock (#7065, #7150)
- Change: Improve ship pathfinder performance
- Change: Decouple GUI timing from game ticks (#6780)
- Change: Desert tiles are now half-desert if a neighboured tile is non-desert or sea/coast (#4754)
- Change: Gradually slow down aircraft speed on breakdown (#6932)
- Change: [NewGRF] Increase rail type & cargo type limits to 64
- Change: [NewGRF] Increase size of persistent storage to 256
- Change: [NewGRF] Use last OpenTTD SVN revision in NewGRF version number (#6843)
- Change: Clone tool in depot window now behaves like clone button in vehicle window (#6754)
- Change #6397: Keep town growth rate in sync with house count
- Change: Scale default FreeType font size selection by UI zoom level
- Change: [OSX] Reversed pinch to zoom behaviour
- Change: Switch town growth rate and counter to actual game ticks (#6763)
- Change: Non-tag revisions are now named '<commitdate>-<branch>-g<shorthash><modified>'
- Change: Rewrite several bits of documentation in markdown
- Fix: Reinitialise graph GUI on game restart (#7191)
- Fix: Potential crash during shutdown after unpacking downloaded content (#7185)
- Fix #6584: Text layout in engine preview dialogue
- Fix #6636: Airplanes could be sent to helicopter station depots
- Fix: Deadlock when launched with -n switch (#7103)
- Fix: Various corrections to town names in non-English languages (#7038, 7141)
- Fix: Only consider airport tiles when placing (for non-rectangular airports) (#6613)
- Fix: Spelling fixes on some Latin American town names
- Fix #7001: Pathfinders should see standard road stations as tiles where to reverse
- Fix #6676: Prevent helicopters from stopping in midair during some kinds of landing
- Fix: Remove need to use Ctrl+Click when building stations next to competitors (#6906)
- Fix: [NewGRF] Make VA2 operator 11 (ror) behave well-defined when rotating by 0 bits
- Fix #4109: Add more water checks to the Oil Rig layout
- Fix #6938: Incorrect value for "Cost to Clear" was displayed for Company Headquarters in tile inspector (#6939)
- Fix #6920: Make 9.8m/s^2 a common constant for TE-calculation
- Fix #6892: [Script] CONFIG_RANDOM did not use the full parameter range (#6902)
- Fix #6622: News message when GS constructs a town had empty company name
- Fix: [NewGRF] Action7 variable 0x85 had no bounds checks
- Fix #6875: Depot building cost did not include foundation build cost (#6883)
- Fix: Some pixels in ship autoreplace icon (sprite 106) were transparent
- Fix: Poor contrast in cargo dest flow legend window cargo labels
- Fix #6553: Make viewport button text unambiguous
- Fix: [OSX] Setting mouse-wheel to scroll the map does not disable pinch to zoom
- Fix #6969: Account for BOM when reading script files
- Fix #6898: Ability to use seeds above INT_MAX (#6936)
- Fix #6659: Bus stations could be demolished when not in demolish mode (#6815)
- Fix: One-way roads could be over-built by road stops regardless of road owner
- Fix: Use name of cargo instead of Passengers/Mail in town statistics (#6801)
- Fix: Prevent ships moving into docks after finishing (un)loading (#6791)
- Fix: Tractive effort was slightly too high as per NewGRF spec (#6785)
- Fix #6465: Add {NORMAL_FONT} and {MONO_FONT} control codes to GS strings (#6726)
- Fix: Four group action icons were misplaced and cropped
- Remove: PSP, WinCE support
* Fri May 18 2018 stefan.bruens@rwth-aachen.de
- Fix compilation with ICU61 (#6690)
  Add fix_issue6690_compilation_with_icu61.patch
- Use SOURCE_DATE_EPOCH as build date, instead of "openSUSE BuildService"
* Mon Apr  2 2018 mimi.vx@gmail.com
- update to new release 1.8.0
  * Feature:
  - [GFX] Climate-specific Action5 extra airport sprites
  - Draw vertical separators at tile distance in the train depot GUI
  - [Build] Project file generator for kdevelop 4/5
  - Add option to close windows with right click
  - Vehicle Group Info: Add profits and occupancy display to group vehicle list
  - Display aircraft type in vehicle preview/purchase/detail windows
  * Change:
  - [NewGRF] Various performance improvements to resolving VA2
  - [NewGRF] Increase maximum allowed vehicle sprite size to reduce
    clipping of ships
  - Check companies for bankruptcy before subtracting reoccuring monthly costs
  - [GFX] Replace the office building sprite on various toyland airports
    with a better fitting sprite
  - [GFX] The switch-toolbar icon contained pixels from the fire cycle.
    Replace the whole icon with a new version
  - Reword texts in industry view, when stockpiling is used
  - Remove the gap between windows when positioning them after opening
  - [Build] Preserve PKG_CONFIG_PATH and PKG_CONFIG_LIBDIR environment
    variables in config.cache file
  - Do not cancel headquarter construction and engine-preview-query
    when shift-clicking
  - Parse extmidi command string for parameters to pass on
  - Draw images in centre of buttons
  * Fix:
  - Store the map variety setting in the savegame like the other mapgen
    settings, so restarting maps considers it
  - Hair selection was missing one option
  - Avoid tile operations outside map border when building lock
  - Catenary sprites got mixed up for depots
  - Make automatic window-positioning RTL-aware
  - Automatic window-positioning now uses GUI-scale/style dependent
    sizes/distances instead of fixed pixel values
  - [NewGRF] While executing random triggers, var 5F should include
    the new triggers
  - [NewGRF] Reset used random triggers only after all A123 chains have
    been resolved, so that all RA2 in all chains can test the shared triggers
  - [NewGRF] Industry random triggers are stored per tile, even when
    randomising the shared random bits of the parent industry
  - [NPF] Reserved track bits were not accounted for when trying to find
    any safe position
  - Do not modify argv[0]
  - Do not search directories when opening ini files as we already have
    their full path
  - Road tunnel/bridge heads have no trackbits wrt. catenary drawing
* Tue Dec 26 2017 vcizek@suse.com
- update to new release 1.7.2
  * Change: When train depots have a horizontal scrollbar, allow
    scrolling 1 tile beyond the longest train, so you can actually
    attach a wagon at the end
  * Fixes:
  - When moving wagons in the depot, the drag highlight did not
    exactly match the length of the dragged wagon chain (r27936)
  - Forest, candyfloss forest and battery farm skipped the first
    animation frame
  - Glyphs in range U+0020 to U+00FF may only be defined in
    orig_extra.grf, not in openttd.grf
  - 'unban' console command was not handling IPv6 adresses properly
  - Keep the 'link' between industry chain and smallmap windows
    whenever possible
  - When the last vehicle is removed from a shared orders group,
    hide the 'Stop sharing' button in the vehicle orders window
  - Tooltip of 'increase service interval' said 'decrease'
  - Console command parser passed invalid strings to the debug
    output, if command lines had many parameters
* Sat Aug  5 2017 jengelh@inai.de
- Update to new maintenance release 1.7.1
  * Add missing game script event for ships arriving at a station
  * Avoid an infinite loop in pathfinder when checking safe
    waiting position from a waypoint
  * YAPF: Consider depot as destination before reversing path and
    applying penalty
  * Don't consider locks or ship depots as clear water when
    placing industries
  * Resolve a failure to load LZO compressed savegames sometimes
* Sun Apr  2 2017 mimi.vx@gmail.com
- update to version 1.7.0
  * Waypoint area is now limited to the max station spread while
    dragging.
  * Rearranged GUI for the vehicle autoreplace feature.
  * Realistic acceleration is now enabled by default for trains
    and road vehicles.
- drop gcc-version-detection.patch - upstreamed
* Sat Jul 16 2016 mailaender@opensuse.org
- Update to version 1.6.1 (see changelog.txt)
- Drop openttd-gcc5.patch as it is not required anymore.
- Add gcc-version-detection.patch in collaboration with upstream.
- Add a man page for the dedicated server binary.
- Remove unnecessary desktop category macros.
- Use standard post macros for icons and starters.
- Eliminate duplicate files using fdupes.
* Thu Jun 16 2016 dimstar@opensuse.org
- Update openttd-gcc5.patch: Have gcc6 use the same flags as gcc5.
* Thu Apr  7 2016 bwiedemann@suse.com
- Fix build-compare
* Sat Dec  5 2015 mailaender@opensuse.org
- maintenance update 1.5.3
  * fixes a long standing desync issue with railtypes
* Thu Oct 15 2015 tchvatal@suse.com
- Version bump to 1.5.2:
  * For details see changelog.txt
* Wed Sep 30 2015 lnussel@suse.de
- build with proper optflags
* Fri Jun 19 2015 dimstar@opensuse.org
- Add openttd-gcc5.patch: Fix build with gcc 5.
* Sat Jun  6 2015 mailaender@opensuse.org
- update to version 1.5.1 (check changelog.txt)
* Sun Apr 26 2015 mailaender@opensuse.org
- Removed openttd-freetype-2.5.4.patch (included by upstream)
- Updated to version 1.5.0
  * higher mountains
  * better UI for high resolution screens
  * much more rural intro screen.
- Recommend adobe-sourcehansans-fonts as backfall when there is no
  sprite font (yet). Workaround https://bugs.openttd.org/task/6226
* Mon Dec 22 2014 dimstar@opensuse.org
- Add openttd-freetype-2.5.4.patch: Fix build with freetype 2.5.4.
- Move the man page to the binary, where it belongs (and drop
  the rpmlintrc-, which is now no longer valid).
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post scripts
* Sun Oct 26 2014 mailaender@opensuse.org
- update to 1.4.4 (check changelog.txt)
* Sun Sep 28 2014 mailaender@opensuse.org
- update to 1.4.3 (bug fix release)
- added missing build requires:
  * libxdg-basedir
  * libtimidity
  * grfcodec
- avoid redundancy in %%description
* Sat Jun 14 2014 mailaender@opensuse.org
- update to 1.4.1 (regular bug fix release)
- use LZMA compressed source
* Fri Apr  4 2014 adrian@suse.de
- update to 1.4.0
  (check changelog.txt)
* Tue Dec 10 2013 suse@ammler.ch
- update to 1.3.3 (security bugfix)
  - many bugfixes including:
    Fix: Aircraft crashing near the map's border due to a lack of airports
    could trigger a crash [CVE-2013-6411] [FS#5820] (bnc#853041)
* Mon Sep 30 2013 suse@ammler.ch
- update to 1.3.2 (bugfix release)
* Sun Jun  2 2013 coder.tux@gmail.com
- update to 1.3.1
* Tue Apr  2 2013 suse@ammler.ch
- update to 1.3.0
  (check changelog.txt)
* Sun Feb 17 2013 suse@ammler.ch
- update to 1.3.0-beta2
  (check changelog.txt)
* Fri Nov  2 2012 suse@ammler.ch
- update to 1.2.3 (bugfix release)
* Thu Aug 16 2012 suse@ammler.ch
- update to 1.2.2
  - many bugfixes including:
    Fix: In some cases ships could be covered with land [FS#5254]
    (CVE-2012-3436, bnc#775023)
* Thu May 31 2012 suse@ammler.ch
- update to 1.2.1
  - many minor bugfixes (see changelog.txt)
* Wed May  9 2012 suse@ammler.ch
- remove BuildRequires hicolor-icon-them (build on SLE_10)
* Fri May  4 2012 suse@ammler.ch
- remove __DATE__ and __TIME__ reference for build-compare
- disable strip so we get debug rpms (also for stable releases)
* Mon Apr 16 2012 suse@ammler.ch
- update to 1.2.0
  * too many changes to list here, please see changelog.txt
    (files data/* moved to baseset/, no gm/ anymore)
* Mon Apr  9 2012 suse@ammler.ch
- remove update-alternatives again (bnc#749128)
- symlink openttd to openttd-dedicated
* Mon Apr  2 2012 suse@ammler.ch
- update to 1.2.0-RC4
* Tue Mar  6 2012 suse@ammler.ch
- upstream update to 1.2.0-RC2
- spec overhaul for openSUSE Factory
* Mon Jan 16 2012 suse@ammler.ch
- upstream update 1.1.5
  * Fix: Make default timeouts for certain network states lower
    and configurable [CVE-2012-0049]
- disable dependency grfcodec
* Tue Dec  6 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Dec  6 2011 suse@ammler.ch
- upstream update 1.1.4
  * various small bugfixes
* Sun Sep 18 2011 ammler@openttdcoop.org
- upstream update 1.1.3
  * Add: River graphics for the original base set
* Wed Aug 17 2011 ammler@openttdcoop.org
- upstream update 1.1.2
- no obs services anymore
* Thu Jun  2 2011 ammler@openttdcoop.org
- upstream update 1.1.1
* Fri Apr  1 2011 ammler@openttdcoop.org
- upstream update 1.1.0
  * Change newgrfs settings aren't allowed anymore on running
    game per default, needs scenario_developer to be set
  * Feature: XZ/LZMA2 savegame support. New default reduces
    savegame size by 10 to 30%% with slightly more CPU usage.
    (requires xz-devel)
  * Feature: Remote administration
  * Feature: a lot improvements with GUI
  * Feature: Customizable hotkeys
  * Sources for openttd.grf are pngs (requires grfcodec >= 5.1)
* Sun Nov 21 2010 ammler@openttdcoop.org
- upstream update 1.0.5
  * Fix: Reading (very) recently freed memory [CVE-2010-4168]
* Sun Oct 31 2010 ammler@openttdcoop.org
- upstream update 1.0.4
  * build openttd.grf from source
* Tue Aug 10 2010 ammler@openttdcoop.org
- upstream update 1.0.3
* Wed Jun 23 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.2
  * Feature: Translated desktop shortcut comments (r19884)
  * many minor Bugfixes
* Sat May  1 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.1
  * Fix: Leaking a file descriptor
  * Fix a lot small bugs, like minor desync issues on Mulitplayer
- no strip on make
* Thu Apr  1 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.0 (finally!)
  * completely independend game but still working also
    with ttd original gaphics, sounds and music
- Add: Recommends openmsx
- requires lzo2
* Fri Dec 18 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.4
- support for differen branches
- easy support for dedicated branch
- let openttd build system make the dektop file
- split the package to data and gui
- disable requires
* Thu Oct  1 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.3
- disable libicu for RHEL4
* Sat Sep 26 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.2
- no subfolder games for datadir
- cleanup: no post and postun anymore
- Recommends: opengfx (for suse and mandriva)
- add SUSE support
* Mon Oct 20 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Added libicu dependency
* Tue Sep 23 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Merged both versions of the spec file
* Fri Aug 29 2008 Jonathan Coome <maedhros@openttd.org>
- Rewrite spec file from scratch.
* Sat Aug  2 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Updated spec file
* Thu Mar 27 2008 Denis Burlaka <burlaka@yandex.ru>
- Universal spec file
